==> kbibtex-trinity_14.0.4.orig.tar.xz: kbibtex-trinity-14.0.4/src/searchbar.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXSEARCHBAR_H
#define KBIBTEXSEARCHBAR_H

#include <ntqwidget.h>

#include <kxmlguifactory.h>

#include <documentlistview.h>
#include <entryfield.h>

class TQTimer;
class KPushButton;
class TDEPopupMenu;
class KHistoryCombo;
class KComboBox;

namespace KBibTeX
{
    /**
    @author Thomas Fischer
    */
    class SearchBar : public TQWidget
    {
        Q_OBJECT
    public:
        SearchBar( TQWidget *parent = 0, const char *name = "search_bar" );
        ~SearchBar();

        void setFactory( KXMLGUIFactory *factory, KXMLGUIClient *client );
        void restoreState();

    signals:
        void doSearch( const TQString &text, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType fieldType );
        void onlineSearch();

    public slots:
        void setSearch( const TQString&text, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType fieldType );

    private:
        KPushButton *m_pushButtonClearSearchText;
        KHistoryCombo *m_comboboxFilter;
        TQTimer *m_timerInput;
        KPushButton *m_pushButtonAddElement;
        KPushButton *m_pushButtonSearchOnlineDatabases;
        KComboBox *m_comboboxFilterType;
        KComboBox *m_comboboxRestrictTo;

        void setupGUI();

    private slots:
        void slotClear();
        void slotTimeout();
        void slotAnnounceDoSearch();
        void slotKeyPressed();
    };

}

#endif

==> kbibtex-trinity_14.0.13.orig.tar.xz: kbibtex-trinity-14.0.13/src/searchbar.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXSEARCHBAR_H
#define KBIBTEXSEARCHBAR_H

#include <tqwidget.h>

#include <kxmlguifactory.h>

#include "documentlistview.h"
#include "entryfield.h"

class TQTimer;
class KPushButton;
class TDEPopupMenu;
class KHistoryCombo;
class KComboBox;

namespace KBibTeX
{
    /**
    @author Thomas Fischer
    */
    class SearchBar : public TQWidget
    {
        Q_OBJECT
    public:
        SearchBar( TQWidget *parent = 0, const char *name = "search_bar" );
        ~SearchBar();

        void setFactory( KXMLGUIFactory *factory, KXMLGUIClient *client );
        void restoreState();

    signals:
        void doSearch( const TQString &text, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType fieldType );
        void onlineSearch();

    public slots:
        void setSearch( const TQString&text, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType fieldType );

    private:
        KPushButton *m_pushButtonClearSearchText;
        KHistoryCombo *m_comboboxFilter;
        TQTimer *m_timerInput;
        KPushButton *m_pushButtonAddElement;
        KPushButton *m_pushButtonSearchOnlineDatabases;
        KComboBox *m_comboboxFilterType;
        KComboBox *m_comboboxRestrictTo;

        void setupGUI();

    private slots:
        void slotClear();
        void slotTimeout();
        void slotAnnounceDoSearch();
        void slotKeyPressed();
    };

}

#endif
